#!/usr/bin/perl

# Script for searching for unused property keys
# Antonio García Domínguez
# $Id$
#
# Licensed under the same terms as Perl itself.
# Requires the 'xargs', 'find' and 'grep' command line utilities.

use strict;
use warnings;
use File::Spec;

# Arguments
if (scalar @ARGV == 0) {
    print STDERR "Usage: $0 [.properties files]\n";
    exit 1;
}
my @files = @ARGV;

# Dump all property keys in a key-position hash
my %keys     = ();
for my $file (@files)
{
    open(IF, "<$file")
	or die "$file couldn't be opened: $!";
    my @lines = <IF>;
    close(IF);

    for my $i (1..$#lines) 
    {
	next if $lines[$i] !~ /^\s*(\S+)\s*=/;
	my $key = $1;

	if (exists $keys{$key}) 
        {
             my ($drive_a, $path_a, $basename_a) = File::Spec->splitpath($keys{$key});
             my ($drive_b, $path_b, $basename_b) = File::Spec->splitpath($file);
             # Name of the resource, minus the _locale part, the extension and the line number
             my ($res_name) = ($basename_a =~ /^([^_\.:]*)(?:_[a-zA-Z_]+)?\./) 
                 or die "Couldn't obtain the base resource name without locale from '$basename_a'";

	     warn "$key has been repeated, and not for l10n (previous position: $keys{$key}, current position: $file:$i)" 
	           if exists $keys{$key} && $basename_b !~ /^\Q$res_name\E(?:_[a-zA-Z_]*)?/;
        }
	$keys{$key} = "$file:$i";
    }
}

# Search for the key in all .java files under the current directory
foreach my $key (sort (keys(%keys)))
{
    my $position = $keys{$key};
    my $output   = `find -name '*.java' -type f | xargs grep -Rl $key`;
    print "Unused key: $key ($position)\n" if $output =~ /^\s*$/;
}

exit 0;
