package es.uca.xmleye.gui;

/*
  Copyright (C) 2005-2008 Antonio García Domínguez

  This program is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation;
  either version 2 of the License, or (at your option) any
  later version.

  This program is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied
  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE. See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA 02111-1307 USA
*/

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.io.File;
import java.io.IOException;
import java.util.ResourceBundle;
import javax.swing.AbstractAction;
import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.KeyStroke;
import javax.swing.WindowConstants;

import es.uca.xmleye.gui.html.*;

/**
 * Diálogo "Acerca De..."
 */
public class WndAbout extends JDialog {
  /**
   *
   */
  private static final long serialVersionUID = -5670307110295788692L;
  private static ResourceBundle res;
  private JButton btnCerrar;
  private JLabel etiqPrograma;
  private JLabel etiqCopyright;
  private JTabbedPane tabExtra;
  private AbstractAction accCerrar;

  static {
    res = ResourceBundle
        .getBundle("es.uca.xmleye.gui.l10n.ResWndAbout");
  }

  /**
   * Crea un nuevo diálogo "Acerca De..." y lo muestra.
   */
  public WndAbout(JFrame padre) {
    super(padre, res.getString("wnd_about"), true);

    inicPropiedades();
    inicAcciones();
    inicComponentes();

    pack();
    setLocationRelativeTo(padre);
    setVisible(true);
  }

  /**
   * Punto de lanzamiento independiente para probar la interfaz gráfica.
   */
  public static void main(String[] args) {
    new WndAbout(null);
  }

  /** Inicializa las propiedades del diálogo. */
  protected void inicPropiedades() {
    setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
    setResizable(false);
    getContentPane().setLayout(new GridBagLayout());
  }

  /** Crea las acciones del diálogo. */
  protected void inicAcciones() {
    accCerrar = new AccionCerrar();
  }

  /**
   * Crea los componentes, establece sus propiedades y los sitúa en el
   * diálogo.
   */
  protected void inicComponentes() {
    GridBagConstraints c = new GridBagConstraints();

    btnCerrar = new JButton(accCerrar);
    etiqPrograma = new JLabel(res.getString("lbl_program"));
    etiqCopyright = new JLabel(res.getString("lbl_copyright"));
    tabExtra = new TabAbout();

    c.gridx = 0;
    c.gridy = 0;
    c.insets = new Insets(12, 12, 11, 11);
    c.anchor = GridBagConstraints.CENTER;
    c.weightx = 0.0;
    c.fill = GridBagConstraints.HORIZONTAL;
    getContentPane().add(etiqPrograma, c);

    c.gridy = 1;
    c.insets = new Insets(0, 12, 11, 11);
    getContentPane().add(etiqCopyright, c);

    c.gridy = 2;
    c.weightx = 1.0;
    c.weighty = 1.0;
    c.fill = GridBagConstraints.BOTH;
    getContentPane().add(tabExtra, c);

    btnCerrar.getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW).put(
        KeyStroke.getKeyStroke("ESCAPE"), "close");
    btnCerrar.getActionMap().put("close", accCerrar);
    c.gridy = 3;
    c.fill = GridBagConstraints.NONE;
    c.insets = new Insets(0, 11, 11, 11);
    c.anchor = GridBagConstraints.LINE_END;
    c.weightx = 0.0;
    c.weighty = 0.0;
    getContentPane().add(btnCerrar, c);
  }

  /**
   * Componente que contiene las dos páginas con la información del programa.
   */
  private class TabAbout extends JTabbedPane {
    /**
     *
     */
    private static final long serialVersionUID = -4359102102936418210L;
    private JPanel pagGracias;
    private JPanel pagLicencia;
    private XHTMLViewerPane htmlGracias;
    private XHTMLViewerPane htmlLicencia;

    /** Crea el componente. */
    public TabAbout() {
      inicComponentes();
      inicPropiedades();
    }

    /** Establece las propiedades del componente. */
    protected void inicPropiedades() {
      setPreferredSize(new Dimension(570, 300));
    }

    /**
     * Crea los componentes internos, establece sus propiedades y los sitúa
     * en el componente.
     */
    protected void inicComponentes() {
      pagGracias = new JPanel(new BorderLayout());
      pagLicencia = new JPanel(new BorderLayout());
      add(res.getString("tab_thanks"), pagGracias);
      add(res.getString("tab_license"), pagLicencia);
      setMnemonicAt(0, ((Integer) res.getObject("tab_thanks_m"))
                    .intValue());
      setMnemonicAt(1, ((Integer) res.getObject("tab_license_m"))
                    .intValue());

      try {
        htmlGracias = new XHTMLViewerPane(
            new File(res.getString("tab_thanks_html")).toURI().toURL());
        htmlLicencia = new XHTMLViewerPane(
            new File(res.getString("tab_license_html")).toURI().toURL());

        htmlGracias.setEditable(false);
        htmlLicencia.setEditable(false);

        htmlGracias.addHyperlinkListener(new ExternalBrowserLinkListener());
        htmlGracias
            .addHyperlinkListener(new AnchorLinkListener());
        htmlLicencia.addHyperlinkListener(new ExternalBrowserLinkListener());
        htmlLicencia
            .addHyperlinkListener(new AnchorLinkListener());

        JScrollPane panelGracias = new JScrollPane();
        htmlGracias.instalar(panelGracias);
        pagGracias.add(panelGracias);

        JScrollPane panelLicencia = new JScrollPane();
        htmlLicencia.instalar(panelLicencia);
        pagLicencia.add(panelLicencia);
      } catch (IOException e) {
        System.err.println(res.getString("err_missing_html"));
        System.exit(1);
      }
    }

  }

  /** Acción de cierre de la ventana. */
  private class AccionCerrar extends AbstractAction {
    /**
     *
     */
    private static final long serialVersionUID = -6656140326597355445L;

    public AccionCerrar() {
      super(res.getString("act_close"));
    }

    public void actionPerformed(ActionEvent e) {
      WndAbout.this.dispose();
    }
  }

}
