package es.uca.xmleye.util;

/*
  Copyright (C) 2008 Antonio García Domínguez

  This program is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation;
  either version 2 of the License, or (at your option) any
  later version.

  This program is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied
  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE. See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA 02111-1307 USA
*/

/**
 * Object which processes a sequence of lines in some way, by accumulating a
 * result or producing some side effect.
 *
 * @author Antonio García Domínguez
 * @version 1.0
 */
public interface LineFilter {

  /**
   * Notifies the filter that EOF has been reached.
   * @throws Exception There was a problem while processing EOF.
   */
  public void eofReached() throws Exception;

  /**
   * Processes a single line from the input. The line might not include
   * the usual "\n", "\r" or "\r\n" line termination sequences.
   *
   * @param line Line read, without the trailing line break.
   * @throws Exception There was a problem while processing the current line.
   */
  void processLine(String line) throws Exception;
}
