package es.uca.xmleye.xslt;

/*
  Copyright (C) 2008 Antonio García Domínguez
  $Id$

  This program is free software; you can redistribute it
  and/or modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation;
  either version 2 of the License, or (at your option) any
  later version.

  This program is distributed in the hope that it will be
  useful, but WITHOUT ANY WARRANTY; without even the implied
  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE. See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public
  License along with this program; if not, write to the Free
  Software Foundation, Inc., 59 Temple Place, Suite 330,
  Boston, MA 02111-1307 USA

*/

import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.*;
import org.w3c.dom.*;

/**
 * Stylesheet de preprocesado de documentos XML.
 */
public class PreprocessingStylesheet extends Stylesheet {
  private String nombre;

  /* --- CONSTRUCTORES --- */
  PreprocessingStylesheet(String pRutaXSLT, String pNombre) {
    super(pRutaXSLT);
    this.nombre = pNombre;
  }

  PreprocessingStylesheet(String pRutaXSLT, URIResolver pResolvedorURI,
                          String pNombre) {
    super(pRutaXSLT, pResolvedorURI);
    this.nombre = pNombre;
  }

  /* --- METODOS PUBLICOS --- */

  /**
   * Devuelve el nombre lógico de la hoja.
   */
  public String getNombre() {
    return this.nombre;
  }

  /**
   * Preprocesa un documento XML ya existente.
   *
   * @param origDoc
   *            Documento XML original a procesar.
   * @return Nuevo documento XML generado por la hoja de preprocesado, o
   *         <code>null</code> si ha habido algún problema.
   */
  public Document preprocesar(Document origDoc)
      throws TransformationException {
    synchronized(origDoc) {
      try {
        final DocumentBuilder docBuilder = DocumentBuilderFactory
            .newInstance().newDocumentBuilder();
        final Document docNuevo = docBuilder.newDocument();

        transformar(new DOMSource(origDoc), new DOMResult(docNuevo));

        return docNuevo;
      } catch (ParserConfigurationException pEx) {
        throw new TransformationException(errRes
                                          .getString("err_conf_xmlparser"), pEx);
      }
    }
  }

}
